# TkReform

Reformed tkinter coding tool.

## Installation

Install TkReform via this command:

```console
pip install tkreform
```

## Usage

TkReform include two different styles of coding - `Imperative` and
`Declarative`.

For the former, you can view [this test script](tests/test.py), or
[this test script](tests/test_declarative.py) for the latter.

## Licensing

TkReform is totally under `MIT License`. You can do everything under
this license.
